@@ -18,11 +18,11 @@ Text::Amuse::Preprocessor - Helpers for Text::Amuse document formatting.
 
 =head1 VERSION
 
-Version 0.32
+Version 0.33
 
 =cut
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
 
 =head1 SYNOPSIS
@@ -285,9 +285,9 @@ sub process {
     }
 
     my $outfile = $self->_outfile;
-    open (my $tmpfh, '<:encoding(utf-8)', $infile)
+    open (my $tmpfh, '<:encoding(UTF-8)', $infile)
       or die "Can't open $infile $!";
-    open (my $auxfh, '>:encoding(utf-8)', $outfile)
+    open (my $auxfh, '>:encoding(UTF-8)', $outfile)
       or die "Can't open $outfile $!";
 
     my $line;
