@@ -65,6 +65,16 @@ sub characters {
                    endash => "\x{2013}",
                    dash =>    "\x{2014}",
                   },
+            sq => {
+                   ldouble => "\x{201c}",
+                   rdouble => "\x{201d}",
+                   lsingle => "\x{2018}",
+                   rsingle => "\x{2019}",
+                   apos => "\x{2019}",
+                   emdash => "\x{2014}",
+                   endash => "\x{2013}",
+                   dash =>    "\x{2014}",
+                  },
             pt => {
                    ldouble => "\x{201c}",
                    rdouble => "\x{201d}",
@@ -269,6 +279,9 @@ sub filter {
         # between spaces, just replace
         $l =~ s/(?<=\S)(\s+)-{1,3}(\s+)(?=\S)/$1$emdash$2/g;
 
+        # end of line with
+        $l =~ s/(?<=\S) +-{1,3}$/ $emdash/;
+
         # -word and word-, in the middle of a line
         $l =~ s/(?<=\S)(\s+)-(\w.+?\w)-(?=\s)/$1$emdash $2 $emdash/g;
 
